# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' Enable internal logging
#'
#' Log entries, depending on the log level, will be printed to the standard
#' error stream.
#'
#' @param log_level A character value, one of "WARN", "INFO", "DEBUG", "VERB",
#'   or "NONE".
#'
#' @keywords internal
init_logging <- function(log_level) {
    invisible(.Call('_bindrcpp_init_logging', PACKAGE = 'bindrcpp', log_level))
}

callback_string_typed <- function(name, fun, payload) {
    .Call('_bindrcpp_callback_string_typed', PACKAGE = 'bindrcpp', name, fun, payload)
}

callback_symbol_typed <- function(name, fun, payload) {
    .Call('_bindrcpp_callback_symbol_typed', PACKAGE = 'bindrcpp', name, fun, payload)
}

callback_string_wrapped <- function(name, fun, payload) {
    .Call('_bindrcpp_callback_string_wrapped', PACKAGE = 'bindrcpp', name, fun, payload)
}

callback_symbol_wrapped <- function(name, fun, payload) {
    .Call('_bindrcpp_callback_symbol_wrapped', PACKAGE = 'bindrcpp', name, fun, payload)
}

do_test_create_environment <- function(names, xform, parent) {
    .Call('_bindrcpp_do_test_create_environment', PACKAGE = 'bindrcpp', names, xform, parent)
}

# Register entry points for exported C++ functions
methods::setLoadAction(function(ns) {
    .Call('_bindrcpp_RcppExport_registerCCallable', PACKAGE = 'bindrcpp')
})
